# -*- coding: utf-8 -*-

#  Copyright © 2013-2015  B. Clausius <barcc@gmx.de>
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .debug import DEBUG_SHADER

N_ = lambda s: s

if DEBUG_SHADER:
    import os
    from . import config
    def shaders(names):
        for filename in os.listdir(config.SHADER_DIR):
            name = os.path.splitext(filename)[0]
            if name not in names:
                names.append(name)
        return names
else:
    shaders = lambda s: s
    
def tuple_validator(minlen, maxlen, itemtype, value, valuerange=None):
    if type(value) is not tuple:
        return False
    if not (minlen <= len(value) <= maxlen):
        return False
    for v in value:
        if type(v) is not itemtype:
            return False
        if valuerange is not None and not valuerange[0] <= v <= valuerange[1]:
            return False
    return True
    
schema = {
    # key:              (default,   range/enum/validator)
    #                               None: value without restriction
    #                               tuple: contains two values (min, max)
    #                               list: contains strings for the enum text,
    #                                     the index is the enum value
    #                               function: returns True, if value is valid
    'window.size':          ((850, 650),lambda v: tuple_validator(2, 2, int, v)),
    'window.divider':       (620,       lambda v: type(v) is int),
    'window.toolbar':       (True,      lambda v: type(v) is bool),
    'window.editbar':       (True,      lambda v: type(v) is bool),
    'window.statusbar':     (True,      lambda v: type(v) is bool),
    #TODO: reintroduce it, but per game.type
    #'draw.default_rotation':((-30.,39.),lambda v: tuple_validator(2, 2, float, v)),
    #TODO: deprecated
    'draw.lighting':        (True,     lambda v: type(v) is bool),
    'draw.shader':          (1,         shaders(['simple', 'lighting'])),
    'draw.selection':       (1,         ['quadrant', 'simple']),
    'draw.speed':           (30,        (1, 100)),
    'game.type':            ('Cube',    lambda v: type(v) is str),
    'game.size':            ((3,4,2),   lambda v: tuple_validator(3, 100, int, v, (1, 10))),
    'game.blocks':          ('solved',  lambda v: type(v) is str),
    'game.moves':           ('',        lambda v: type(v) is str),
    'game.position':        (0,         lambda v: type(v) is int and v >= 0),
    'theme.face.0.color':   ('#a81407', lambda v: type(v) is str),
    'theme.face.1.color':   ('#d94b1c', lambda v: type(v) is str),
    'theme.face.2.color':   ('#f0c829', lambda v: type(v) is str),
    'theme.face.3.color':   ('#e3e3e3', lambda v: type(v) is str),
    'theme.face.4.color':   ('#1d6311', lambda v: type(v) is str),
    'theme.face.5.color':   ('#00275e', lambda v: type(v) is str),
    'theme.face.*.image':   ('',        lambda v: type(v) is str),
    'theme.face.*.mode':    (0,         ['tiled', 'mosaic']),
    'theme.bgcolor':        ('#B9a177', lambda v: type(v) is str),
    'draw.accels':          ([('r', 'KP+6'), ('r-', 'Shift+KP+Right'),
                              ('l', 'KP+4'), ('l-', 'Shift+KP+Left'),
                              ('u', 'KP+8'), ('u-', 'Shift+KP+Up'),
                              ('d', 'KP+2'), ('d-', 'Shift+KP+Down'),
                              ('f', 'KP+5'), ('f-', 'Shift+KP+Clear'),
                              ('b', 'KP+0'), ('b-', 'Shift+KP+Ins'),
                              ('R', 'Ctrl+KP+8'), ('L', 'Ctrl+KP+2'),
                              ('U', 'Ctrl+KP+4'), ('D', 'Ctrl+KP+6'),
                              ('F', 'Ctrl+KP+5'), ('B', 'Ctrl+KP+0'),
                             ],         lambda v: type(v) is list),
    'draw.zoom':            (1.4,       (0.1, 100.0)),
    # The following 6 words are for the antialiasing levels: disabled, ugly, low, medium, high, higher
    'draw.samples':         (3,         [N_('disabled'), N_('ugly'), N_('low'),
                                         N_('medium'), N_('high'), N_('higher')]),
    'draw.mirror_faces':    (False,     lambda v: type(v) is bool),
    'draw.mirror_distance': (2.1,       (0.1, 10.0)),
    'action.edit_moves':    ('Ctrl+L',  lambda v: type(v) is str),
    'action.edit_cube':     ('',        lambda v: type(v) is str),
    'action.selectmodel':   ('Ctrl+M',  lambda v: type(v) is str),
    'action.initial_state': ('',        lambda v: type(v) is str),
    'action.reset_rotation':('Ctrl+R',  lambda v: type(v) is str),
    'action.preferences':   ('Ctrl+P',  lambda v: type(v) is str),
   }

